ProtocolVersion

Enum ProtocolVersion 

pub enum ProtocolVersion {
    V1 = 1,
    V2 = 2,
    V3 = 3,
}
Transport-scoped protocol version identifier used by the ingestion APIs.

Interpret this value together with the transport protocol. The same version number may correspond to different wire formats or feature sets on different transports.

Variants



V1 = 1

Version 1.



V2 = 2

Version 2.



V3 = 3

Version 3.