#[non_exhaustive]pub enum QwpWsErrorCategory {
SchemaMismatch,
ParseError,
InternalError,
SecurityError,
WriteError,
NotWritable,
ProtocolViolation,
Unknown,
}Expand description
Server-distinguishable QWP/WebSocket error category.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
SchemaMismatch
Server-side schema mismatch, such as a missing column, type clash, or NOT NULL violation.
ParseError
Malformed QWP payload.
InternalError
Server-side internal failure.
SecurityError
Authentication or authorization failure.
WriteError
Non-critical server write failure.
NotWritable
Server reports that the endpoint is temporarily not writable.
ProtocolViolation
WebSocket protocol violation, including poison-frame escalation.
Unknown
Unknown QWP status byte.