#[non_exhaustive]pub enum QwpWsErrorPolicy {
Retriable,
RetriableOther,
Terminal,
}Expand description
Policy applied by the sender after observing a QWP/WebSocket server error.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Retriable
Tear down the connection, reconnect, and replay from the unresolved store-and-forward watermark.
RetriableOther
Tear down and replay, but classify separately for diagnostics because another endpoint/role may be required.
Terminal
Latch the error as terminal. The bytes remain in store-and-forward storage for inspection or a later compatible client/server.