ColumnName

Struct ColumnName 

pub struct ColumnName<'a> { /* private fields */ }
A validated column name.

This type simply wraps a &str.

When you pass a ColumnName instead of a plain string to a Buffer method, it doesn’t have to validate it again. This saves CPU cycles.

Implementations

Source

impl<'a> ColumnName<'a>

pub fn new(name: &'a str) -> Result<Self>

Construct a validated column name.

pub fn new_unchecked(name: &'a str) -> Self

Construct a column name without validating it.

This breaks API encapsulation and is only intended for use when the string was already previously validated.

The QuestDB server will reject an invalid column name.