TableName

Struct TableName 

pub struct TableName<'a> { /* private fields */ }
A validated table name.

This type simply wraps a &str.

When you pass a TableName instead of a plain string to a Buffer method, it doesn’t have to validate it again. This saves CPU cycles.

Implementations

Source

impl<'a> TableName<'a>

pub fn new(name: &'a str) -> Result<Self>

Construct a validated table name.

pub fn new_unchecked(name: &'a str) -> Self

Construct a table name without validating it.

This breaks API encapsulation and is only intended for use when the string was already previously validated.

The QuestDB server will reject an invalid table name.