ErrorCode

Enum ErrorCode 

pub enum ErrorCode {
Show 14 variants CouldNotResolveAddr, InvalidApiCall, SocketError, InvalidUtf8, InvalidName, InvalidTimestamp, AuthError, TlsError, HttpNotSupported, ServerFlushError, ConfigError, ArrayError, ProtocolVersionError, InvalidDecimal,
}
Category of error.

Accessible via Error’s code method.

Variants



CouldNotResolveAddr

The host, port, or interface was incorrect.



InvalidApiCall

Called methods in the wrong order. E.g. symbol after column.



SocketError

A network error connecting or flushing data out.



InvalidUtf8

The string or symbol field is not encoded in valid UTF-8.

This error is reserved for the C and C++ API.



InvalidName

The table name or column name contains bad characters.



InvalidTimestamp

The supplied timestamp is invalid.



AuthError

Error during the authentication process.



TlsError

Error during TLS handshake.



HttpNotSupported

The server does not support ILP-over-HTTP.



ServerFlushError

Error sent back from the server during flush.



ConfigError

Bad configuration.



ArrayError

There was an error serializing an array.



ProtocolVersionError

Validate protocol version error.



InvalidDecimal

The supplied decimal is invalid.